@@ -3,4 +3,4 @@ from instrument_server.errors import CommandError
 
 class RaiseErrorMixin:
     def raise_error(self, message):
-        raise CommandError(f'{self.command} error: {message}')
+        raise CommandError(f'{self.command}: {message}')
