@@ -9,12 +9,11 @@ class QuitCommand(BasicCommand):
     """
 
     # definition
-    COMMAND = 'quit'
-    ARGS    = {}
+    command = 'quit'
+    args    = {}
 
     # implementation
     def code(self, devices, args):
-        print('goodbye')
         sys.exit(0)
 
 
