@@ -1,5 +1,5 @@
 def is_plugin(module):
-    try:
+    try:  # IS_COMMAND_PLUGIN?
         module.IS_COMMAND_PLUGIN
         return True
     except:
