@@ -1,5 +1,5 @@
 def is_plugin(module):
-    try:
+    try:  # IS_DEVICE_PLUGIN
         module.IS_DEVICE_PLUGIN
         return True
     except:
